#ifndef SRMRENDERMODEITSELF_H
#define SRMRENDERMODEITSELF_H

#include <SRMTypes.h>

#ifdef __cplusplus
extern "C" {
#endif

void srmRenderModeItselfSetInterface(SRMConnector *connector);

#ifdef __cplusplus
}
#endif

#endif // SRMRENDERMODEITSELF_H
